==> p5-Gtk-0.7009_2.tbz: lib/perl5/site_perl/5.8.8/mach/Gtk/Install/Files.pm <==
#!/usr/bin/perl

package Gtk::Install::Files;

@boot = qw(
	Gtk::Selection
	Gtk11
	Gtk::Toolbar116
	Gtk__AccelGroup
	Gtk::ProgressBar11
	Gtk::CList12
	Gtk12
);

@c = qw(
	build/GtkDefs.c
	build/PerlGtkExt.c
	GdkTypes.c
	GtkTypes.c
	MiscTypes.c
	Derived.c
);

@defines = qw(
	-DPERL_POLLUTE
	-DLAZY_LOAD
	-DGTK_HVER=0x01020a -o $*.o
);

@defs = qw(
	gtk-0.99.defs
	gtk-1.0.defs
	gtk-1.1.defs
	gtk-1.1.1.defs
	gtk-1.1.3.defs
	gtk-1.1.4.defs
	gtk-1.1.6.defs
	gtk-1.2.defs
);

@headers = qw(
	<gtk/gtk.h>
	<gtk/gtkinvisible.h>
	"GtkTypes.h"
	"GdkTypes.h"
	"MiscTypes.h"
);

@typemaps = qw(
	GtkTypemap
	gtk-0.99.typemap
	gtk-1.2.typemap
);

@xs = qw(
	xs/Gtk.xs
	xs/Gtk-1.1.xs
	xs/GtkToolbar-1.1.6.xs
	xs/GtkAccelGroup.xs
	xs/GtkProgressBar-1.1.xs
	xs/GtkCList-1.2.xs
	xs/Gtk-1.2.xs
	xs/GtkSelection.xs
	xs/GtkAccelLabel.xs
	xs/GtkAdjustment.xs
	xs/GtkAlignment.xs
	xs/GtkArrow.xs
	xs/GtkAspectFrame.xs
	xs/GtkBin.xs
	xs/GtkBox.xs
	xs/GtkButton.xs
	xs/GtkButtonBox.xs
	xs/GtkCList.xs
	xs/GtkCTree.xs
	xs/GtkCalendar.xs
	xs/GtkCheckButton.xs
	xs/GtkCheckMenuItem.xs
	xs/GtkColorSelection.xs
	xs/GtkColorSelectionDialog.xs
	xs/GtkCombo.xs
	xs/GtkContainer.xs
	xs/GtkCurve.xs
	xs/GtkData.xs
	xs/GtkDialog.xs
	xs/GtkDrawingArea.xs
	xs/GtkEditable.xs
	xs/GtkEntry.xs
	xs/GtkEventBox.xs
	xs/GtkFileSelection.xs
	xs/GtkFixed.xs
	xs/GtkFontSelection.xs
	xs/GtkFontSelectionDialog.xs
	xs/GtkFrame.xs
	xs/GtkGammaCurve.xs
	xs/GtkHBox.xs
	xs/GtkHButtonBox.xs
	xs/GtkHPaned.xs
	xs/GtkHRuler.xs
	xs/GtkHScale.xs
	xs/GtkHScrollbar.xs
	xs/GtkHSeparator.xs
	xs/GtkHandleBox.xs
	xs/GtkImage.xs
	xs/GtkInputDialog.xs
	xs/GtkInvisible.xs
	xs/GtkItem.xs
	xs/GtkItemFactory.xs
	xs/GtkLabel.xs
	xs/GtkLayout.xs
	xs/GtkList.xs
	xs/GtkListItem.xs
	xs/GtkMenu.xs
	xs/GtkMenuBar.xs
	xs/GtkMenuItem.xs
	xs/GtkMenuShell.xs
	xs/GtkMisc.xs
	xs/GtkNotebook.xs
	xs/GtkObject.xs
	xs/GtkOptionMenu.xs
	xs/GtkPacker.xs
	xs/GtkPaned.xs
	xs/GtkPixmap.xs
	xs/GtkPlug.xs
	xs/GtkPreview.xs
	xs/GtkProgress.xs
	xs/GtkProgressBar.xs
	xs/GtkRadioButton.xs
	xs/GtkRadioMenuItem.xs
	xs/GtkRange.xs
	xs/GtkRuler.xs
	xs/GtkScale.xs
	xs/GtkScrollbar.xs
	xs/GtkScrolledWindow.xs
	xs/GtkSeparator.xs
	xs/GtkSocket.xs
	xs/GtkSpinButton.xs
	xs/GtkStatusbar.xs
	xs/GtkTable.xs
	xs/GtkTearoffMenuItem.xs
	xs/GtkText.xs
	xs/GtkTipsQuery.xs
	xs/GtkToggleButton.xs
	xs/GtkToolbar.xs
	xs/GtkTooltips.xs
	xs/GtkTree.xs
	xs/GtkTreeItem.xs
	xs/GtkVBox.xs
	xs/GtkVButtonBox.xs
	xs/GtkVPaned.xs
	xs/GtkVRuler.xs
	xs/GtkVScale.xs
	xs/GtkVScrollbar.xs
	xs/GtkVSeparator.xs
	xs/GtkViewport.xs
	xs/GtkWidget.xs
	xs/GtkWindow.xs
);

$libs = '-L/usr/local/lib -L/usr/X11R6/lib -lgtk-12 -lgdk-12 -Wl,-E -lgmodule-12 -lglib-12 -lintl -lXi -lXext -lX11 -lm ';
$inc = '-I/usr/local/include/gtk12 -I/usr/local/include/glib12 -I/usr/local/include -I/usr/X11R6/include  -I. -I./build';

	$CORE = undef;
	foreach (@INC) {
		if ( -f $_ . "/Gtk/Install/Files.pm") {
			$CORE = $_ . "/Gtk/Install/";
			last;
		}
	}

	1;

==> p5-Gtk-0.7009_4.tbz: lib/perl5/site_perl/5.8.8/mach/Gtk/Install/Files.pm <==
#!/usr/bin/perl

package Gtk::Install::Files;

@boot = qw(
	Gtk::Selection
	Gtk11
	Gtk::Toolbar116
	Gtk__AccelGroup
	Gtk::ProgressBar11
	Gtk::CList12
	Gtk12
);

@c = qw(
	build/GtkDefs.c
	build/PerlGtkExt.c
	GdkTypes.c
	GtkTypes.c
	MiscTypes.c
	Derived.c
);

@defines = qw(
	-DPERL_POLLUTE
	-DLAZY_LOAD
	-DGTK_HVER=0x01020a -o $*.o
);

@defs = qw(
	gtk-0.99.defs
	gtk-1.0.defs
	gtk-1.1.defs
	gtk-1.1.1.defs
	gtk-1.1.3.defs
	gtk-1.1.4.defs
	gtk-1.1.6.defs
	gtk-1.2.defs
);

@headers = qw(
	<gtk/gtk.h>
	<gtk/gtkinvisible.h>
	"GtkTypes.h"
	"GdkTypes.h"
	"MiscTypes.h"
);

@typemaps = qw(
	GtkTypemap
	gtk-0.99.typemap
	gtk-1.2.typemap
);

@xs = qw(
	xs/Gtk.xs
	xs/Gtk-1.1.xs
	xs/GtkToolbar-1.1.6.xs
	xs/GtkAccelGroup.xs
	xs/GtkProgressBar-1.1.xs
	xs/GtkCList-1.2.xs
	xs/Gtk-1.2.xs
	xs/GtkSelection.xs
	xs/GtkAccelLabel.xs
	xs/GtkAdjustment.xs
	xs/GtkAlignment.xs
	xs/GtkArrow.xs
	xs/GtkAspectFrame.xs
	xs/GtkBin.xs
	xs/GtkBox.xs
	xs/GtkButton.xs
	xs/GtkButtonBox.xs
	xs/GtkCList.xs
	xs/GtkCTree.xs
	xs/GtkCalendar.xs
	xs/GtkCheckButton.xs
	xs/GtkCheckMenuItem.xs
	xs/GtkColorSelection.xs
	xs/GtkColorSelectionDialog.xs
	xs/GtkCombo.xs
	xs/GtkContainer.xs
	xs/GtkCurve.xs
	xs/GtkData.xs
	xs/GtkDialog.xs
	xs/GtkDrawingArea.xs
	xs/GtkEditable.xs
	xs/GtkEntry.xs
	xs/GtkEventBox.xs
	xs/GtkFileSelection.xs
	xs/GtkFixed.xs
	xs/GtkFontSelection.xs
	xs/GtkFontSelectionDialog.xs
	xs/GtkFrame.xs
	xs/GtkGammaCurve.xs
	xs/GtkHBox.xs
	xs/GtkHButtonBox.xs
	xs/GtkHPaned.xs
	xs/GtkHRuler.xs
	xs/GtkHScale.xs
	xs/GtkHScrollbar.xs
	xs/GtkHSeparator.xs
	xs/GtkHandleBox.xs
	xs/GtkImage.xs
	xs/GtkInputDialog.xs
	xs/GtkInvisible.xs
	xs/GtkItem.xs
	xs/GtkItemFactory.xs
	xs/GtkLabel.xs
	xs/GtkLayout.xs
	xs/GtkList.xs
	xs/GtkListItem.xs
	xs/GtkMenu.xs
	xs/GtkMenuBar.xs
	xs/GtkMenuItem.xs
	xs/GtkMenuShell.xs
	xs/GtkMisc.xs
	xs/GtkNotebook.xs
	xs/GtkObject.xs
	xs/GtkOptionMenu.xs
	xs/GtkPacker.xs
	xs/GtkPaned.xs
	xs/GtkPixmap.xs
	xs/GtkPlug.xs
	xs/GtkPreview.xs
	xs/GtkProgress.xs
	xs/GtkProgressBar.xs
	xs/GtkRadioButton.xs
	xs/GtkRadioMenuItem.xs
	xs/GtkRange.xs
	xs/GtkRuler.xs
	xs/GtkScale.xs
	xs/GtkScrollbar.xs
	xs/GtkScrolledWindow.xs
	xs/GtkSeparator.xs
	xs/GtkSocket.xs
	xs/GtkSpinButton.xs
	xs/GtkStatusbar.xs
	xs/GtkTable.xs
	xs/GtkTearoffMenuItem.xs
	xs/GtkText.xs
	xs/GtkTipsQuery.xs
	xs/GtkToggleButton.xs
	xs/GtkToolbar.xs
	xs/GtkTooltips.xs
	xs/GtkTree.xs
	xs/GtkTreeItem.xs
	xs/GtkVBox.xs
	xs/GtkVButtonBox.xs
	xs/GtkVPaned.xs
	xs/GtkVRuler.xs
	xs/GtkVScale.xs
	xs/GtkVScrollbar.xs
	xs/GtkVSeparator.xs
	xs/GtkViewport.xs
	xs/GtkWidget.xs
	xs/GtkWindow.xs
);

$libs = '-L/usr/local/lib -L/usr/local/lib -lgtk-12 -lgdk-12 -lgmodule-12 -lglib-12 -lintl -lXi -lXext -lX11 -lm ';
$inc = '-I/usr/local/include/gtk12 -I/usr/local/include/glib12 -I/usr/local/include -I/usr/local/include  -I. -I./build';

	$CORE = undef;
	foreach (@INC) {
		if ( -f $_ . "/Gtk/Install/Files.pm") {
			$CORE = $_ . "/Gtk/Install/";
			last;
		}
	}

	1;
